@@ -2,7 +2,7 @@ package Catmandu::Importer::WoS;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0303';
 
 use Moo;
 use Catmandu::Util qw(xml_escape);
@@ -11,6 +11,7 @@ use namespace::clean;
 with 'Catmandu::WoS::SearchRecords';
 
 has query             => (is => 'ro', required => 1);
+has edition           => (is => 'ro');
 has symbolic_timespan => (is => 'ro');
 has timespan_begin    => (is => 'ro');
 has timespan_end      => (is => 'ro');
@@ -20,9 +21,15 @@ sub _search_content {
 
     my $query = xml_escape($self->query);
 
+    my $edition_xml           = '';
     my $symbolic_timespan_xml = '';
     my $timespan_xml          = '';
 
+    if (my $edition = $self->edition) {
+        $edition_xml
+            = "<editions><collection>WOS</collection><edition>$edition</edition></editions>";
+    }
+
     if (my $ts = $self->symbolic_timespan) {
         $symbolic_timespan_xml = "<symbolicTimeSpan>$ts</symbolicTimeSpan>";
     }
@@ -42,6 +49,7 @@ sub _search_content {
          <queryParameters>
             <databaseId>WOS</databaseId>
             <userQuery>$query</userQuery>
+            $edition_xml
             $symbolic_timespan_xml
             $timespan_xml
             <queryLanguage>en</queryLanguage>
@@ -83,6 +91,7 @@ Catmandu::Importer::WoS - Import Web of Science records
     # On the command line
 
     $ catmandu convert WoS --username XXX --password XXX --query 'TS=(lead OR cadmium)' to YAML
+    $ catmandu convert WoS --username XXX --password XXX --query 'TS=(lead OR cadmium)' --edition SCI to YAML
 
     # In perl
 
